Learn R Programming

kinesis (version 0.3.1)

footer_ui: Footer UI

Description

Footer UI

Usage

footer_ui(id)

Value

A list that can be converted into an HTML <footer> tag (see htmltools::tags()).

Arguments

id

A character vector to be used for the namespace.

See Also

footer_server()

Other page modules: footer_server(), home_server(), home_ui()