Learn R Programming

kinesis (version 0.3.1)

get_option: Get App Options

Description

Get App Options

Usage

get_option(name = NULL, default = NULL)

Value

The value of a Shiny option (see shiny::getShinyOption()).

Arguments

name

A character string specifying the name of an option to get. If NULL (the default), all options are returned.

default

A value to be returned if the option is not currently set.

Author

N. Frerebeau