Learn R Programming

kinesis (version 0.3.1)

scatter_ui: Scatter Plot UI

Description

Scatter Plot UI

Usage

scatter_ui(id)

Value

A nav item that may be passed to a nav container (e.g. bslib::navset_tab()).

Arguments

id

A character vector to be used for the namespace.

See Also

scatter_server()

Other plot modules: graphics_server(), graphics_ui(), scatter_server(), ternary_server(), ternary_ui()