Learn R Programming

kinesis (version 0.3.1)

ternary_ui: Ternary Plot UI

Description

Ternary Plot UI

Usage

ternary_ui(id)

Value

A nav item that may be passed to a nav container (e.g. bslib::navset_tab()).

Arguments

id

A character vector to be used for the namespace.

See Also

ternary_server()

Other plot modules: graphics_server(), graphics_ui(), scatter_server(), scatter_ui(), ternary_server()