Learn R Programming

kinesis (version 0.3.1)

update_checkbox_colnames: Update a Checkbox Group with Column Names

Description

Update a Checkbox Group with Column Names

Usage

update_checkbox_colnames(id, x, exclude = reactive(NULL), select = TRUE)

Value

A reactive character vector of column names.

Side effect: change the value of a checkbox group on the client.

Arguments

id

A character string specifying the namespace.

x

A reactive matrix-like object.

exclude

A reactive character vector of values to be excluded from choices.

select

A logical scalar: should all choices be selected?

See Also

checkbox_ui()