powered by
Footer UI
footer_ui(id)
A list that can be converted into an HTML <footer> tag (see htmltools::tags()).
list
<footer>
htmltools::tags()
A character vector to be used for the namespace.
character
footer_server()
Other page modules: footer_server(), home_server(), home_ui()
home_server()
home_ui()