get_option: Get App Options
Description
Get App Options
Usage
get_option(name = NULL, default = NULL)
Arguments
- name
A character string specifying the name of an option to get.
If NULL (the default), all options are returned.
- default
A value to be returned if the option is not currently set.